@@ -28,7 +28,7 @@ fn impl_checkout_server(ast: &syn::DeriveInput) -> TokenStream {
             pub use checkout_core::dropshot::TypedBody;
             pub use checkout_core::http::StatusCode;
             pub use checkout_core::{
-                error::Error, money::Currency, Checkout, Context, ContextProvider, server::Server,
+                error::Error, money::Currency, Checkout, Context, server::Server,
             };
 
             use std::sync::Arc;
@@ -36,7 +36,7 @@ fn impl_checkout_server(ast: &syn::DeriveInput) -> TokenStream {
             use checkout_core::server::CreateRequest;
 
             pub struct ServerContext {
-                pub context_provider: super::#name
+                pub context_provider: super::CheckoutServer
             }
 
             #[endpoint {
@@ -74,7 +74,7 @@ fn impl_checkout_server(ast: &syn::DeriveInput) -> TokenStream {
             }
         }
 
-        impl checkout_server::Server for #name {
+        impl checkout_server::Server<#name> for CheckoutServer {
             type Context = checkout_server::ServerContext;
 
             fn api_description() -> checkout_server::ApiDescription<checkout_server::ServerContext> {
